import { world, system } from "@minecraft/server";

let trackedDrops = new Map();

// Track entity deaths and store player UUID if a player killed the entity
world.afterEvents.entityDie.subscribe((event) => {
    const entity = event.deadEntity;
    const damageSource = event.damageSource;

    if (damageSource && damageSource.damagingEntity?.typeId === "minecraft:player") {
        let playerId = damageSource.damagingEntity.id;
        trackedDrops.set(entity.id, playerId);
    }
});

// Check dropped items and add them to the correct player's inventory
system.runInterval(() => {
    for (const item of world.getAllEntities({ type: "minecraft:item" })) {
        let entityId = item.id;
        if (trackedDrops.has(entityId)) {
            let playerId = trackedDrops.get(entityId);
            let player = world.getAllPlayers().find(p => p.id === playerId);
            
            if (player && item.hasComponent("minecraft:item")) {
                let itemStack = item.getComponent("minecraft:item").itemStack;
                
                try {
                    if (player.getComponent("minecraft:inventory").container.addItem(itemStack)) {
                        item.remove(); // Remove the item entity after pickup
                        trackedDrops.delete(entityId); // Remove the entry from trackedDrops
                    }
                } catch (error) {
                    console.error(`Failed to add item to player inventory: ${error}`);
                }
            }
        }
    }
}, 10); // Runs every 10 ticks (~0.5 seconds);
    }

    // Apply Fortune multiplier
    let fortuneMultiplier = 1;
    if (fortuneLevel > 0) {
        fortuneMultiplier += Math.floor(Math.random() * (fortuneLevel + 1));
    }

    // Calculate final drop count
    const totalDrop = baseDrop * fortuneMultiplier;
    const itemStack = new ItemStack(smeltedItem, totalDrop);
    
    // Spawn smelted item and give XP
    block.dimension.spawnItem(itemStack, block.location);
    block.dimension.runCommand(`xp ${totalDrop}L ${player.name}`);
});